# pymydumper

[![PyPI - Version](https://img.shields.io/pypi/v/testhatch.svg)](https://pypi.org/project/pymydumper)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/testhatch.svg)](https://pypi.org/project/pymydumper)

-----

`pymydumper` is a Python-based tool inspired by [https://github.com/mydumper/mydumper](mydumper) to easily and quickly
create logical backups of MySQL or MariaDB databases. It's been written from the ground up to guarantee consistency and
speed, being tested in databases over 10's of TB in size.

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install testhatch
```

## License

`pymydumper` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
